@@ -31,6 +31,19 @@ import de.thetaphi.forbiddenapis.gradle.CheckForbiddenApis
 import de.thetaphi.forbiddenapis.gradle.CheckForbiddenApisExtension
 import org.gradle.api.tasks.testing.logging.TestExceptionFormat
 
+buildscript {
+    dependencies {
+        constraints {
+            "classpath"("org.ow2.asm:asm:${property("asm.version")}")
+            "classpath"("org.ow2.asm:asm-all:${property("asm.version")}")
+            "classpath"("org.ow2.asm:asm-analysis:${property("asm.version")}")
+            "classpath"("org.ow2.asm:asm-commons:${property("asm.version")}")
+            "classpath"("org.ow2.asm:asm-tree:${property("asm.version")}")
+            "classpath"("org.ow2.asm:asm-util:${property("asm.version")}")
+        }
+    }
+}
+
 plugins {
     publishing
     // Verification
@@ -65,6 +78,7 @@ val enableSpotBugs = props.bool("spotbugs", default = false)
 val skipCheckstyle by props()
 val skipAutostyle by props()
 val skipJavadoc by props()
+var nvdApiKey: String? = props.string("nvdApiKey")
 // Inherited from stage-vote-release-plugin: skipSign, useGpgCmd
 val enableMavenLocal by props()
 val enableGradleMetadata by props()
@@ -146,7 +160,7 @@ val javadocAggregate by tasks.registering(Javadoc::class) {
 
     classpath = files(sourceSets.map { set -> set.map { it.output + it.compileClasspath } })
     setSource(sourceSets.map { set -> set.map { it.allJava } })
-    setDestinationDir(file("$buildDir/docs/javadocAggregate"))
+    setDestinationDir(file(layout.buildDirectory.get().file("docs/javadocAggregate")))
 }
 
 /** Similar to {@link #javadocAggregate} but includes tests.
@@ -161,7 +175,16 @@ val javadocAggregateIncludingTests by tasks.registering(Javadoc::class) {
 
     classpath = files(sourceSets.map { set -> set.map { it.output + it.compileClasspath } })
     setSource(sourceSets.map { set -> set.map { it.allJava } })
-    setDestinationDir(file("$buildDir/docs/javadocAggregateIncludingTests"))
+    setDestinationDir(file(layout.buildDirectory.get().file("docs/javadocAggregateIncludingTests")))
+}
+
+if (nvdApiKey != null) {
+    apply(plugin = "org.owasp.dependencycheck")
+    dependencyCheck {
+        nvd {
+            apiKey = nvdApiKey
+        }
+    }
 }
 
 allprojects {
@@ -236,6 +259,7 @@ allprojects {
         fileMode = "664".toInt(8)
     }
 
+    tasks.register<DependencyReportTask>("allDependencies") {}
     tasks {
         withType<Javadoc>().configureEach {
             (options as StandardJavadocDocletOptions).apply {
@@ -267,7 +291,7 @@ allprojects {
     }
 
     plugins.withType<JavaPlugin> {
-        configure<JavaPluginConvention> {
+        configure<JavaPluginExtension> {
             sourceCompatibility = JavaVersion.VERSION_1_8
             targetCompatibility = JavaVersion.VERSION_1_8
         }
@@ -334,16 +358,6 @@ allprojects {
                 // By default spotbugs verifies TEST classes as well, and we do not want that
                 this.sourceSets = listOf(sourceSets["main"])
             }
-            dependencies {
-                constraints {
-                    "spotbugs"("org.ow2.asm:asm:${"asm".v}")
-                    "spotbugs"("org.ow2.asm:asm-all:${"asm".v}")
-                    "spotbugs"("org.ow2.asm:asm-analysis:${"asm".v}")
-                    "spotbugs"("org.ow2.asm:asm-commons:${"asm".v}")
-                    "spotbugs"("org.ow2.asm:asm-tree:${"asm".v}")
-                    "spotbugs"("org.ow2.asm:asm-util:${"asm".v}")
-                }
-            }
         }
 
         configure<CheckForbiddenApisExtension> {
@@ -390,6 +404,7 @@ allprojects {
 
             withType<JavaCompile>().configureEach {
                 options.encoding = "UTF-8"
+                options.compilerArgs.addAll(listOf("-Xlint:deprecation,-options", "-Werror"))
             }
             withType<Test>().configureEach {
                 testLogging {
@@ -469,11 +484,12 @@ allprojects {
             archives(sourcesJar)
         }
 
-        val archivesBaseName = when (path) {
-            ":shaded:avatica" -> "avatica"
-            else -> "avatica-$name"
+        base {
+            archivesName.set(when (path) {
+                ":shaded:avatica" -> "avatica"
+                else -> "avatica-$name"
+            })
         }
-        setProperty("archivesBaseName", archivesBaseName)
 
         configure<PublishingExtension> {
             if (project.path == ":") {
@@ -483,7 +499,7 @@ allprojects {
             extraMavenPublications()
             publications {
                 create<MavenPublication>(project.name) {
-                    artifactId = archivesBaseName
+                    artifactId = base.archivesName.get()
                     version = rootProject.version.toString()
                     description = project.description
                     from(components["java"])
