@@ -31,9 +31,11 @@ plugins {
 //   and "implementation" is for dependencies that do not participate in API
 dependencies {
     api(project(":metrics"))
+    api(platform("com.fasterxml.jackson:jackson-bom"))
     api("com.fasterxml.jackson.core:jackson-annotations")
     api("com.fasterxml.jackson.core:jackson-databind")
     api("com.google.protobuf:protobuf-java")
+    api("org.jooq:joou-java-6")
     implementation("com.fasterxml.jackson.core:jackson-core")
     implementation("org.apache.httpcomponents.client5:httpclient5")
     implementation("org.apache.httpcomponents.core5:httpcore5")
